import { StrictOmit } from "ts-essentials";
import defaultRepository from "../../repository/dataRepository";
export interface URLDataSyncInProps<Data> {
    readonly data: Data | null | undefined;
    readonly dataError: Error | null | undefined;
    readonly isLoadingData: boolean;
    getData(): void;
    saveData(): void;
    updateData(data: Partial<Data>): void;
    getURLQuery(): URLQueryMap;
    /** Update URL query parameters without reloading and trigger a re-sync. */
    replaceURLQuery(query: URLQueryMap): void;
    /** Instead of setting URL query, append to existing URL query. */
    appendURLQuery(query: URLQueryMap): void;
}
export interface URLDataSyncOutProps {
    overrideConfiguration?: StrictOmit<HTTPClient.Config, "data" | "method" | "params">;
    syncRepository?: typeof defaultRepository;
}
/**
 * Automatically sync with current URL by requesting data from server using
 * said URL. This is assuming there is data provided by the server at current
 * URL, e.g. user navigates to /users/1, this will send a GET request to
 * /users/1, which should have a defined backend route that contains the
 * relevant data.
 *
 * This HOC is usually used for components rendered by a Route. Please make sure
 * when implementing the backend to handle these requests that it never returns
 * null/undefined (as per REST design standards).
 */
export declare function urlDataSyncHOC<Data>(syncRepository?: typeof defaultRepository, overrideConfig?: URLDataSyncOutProps["overrideConfiguration"]): FunctionalEnhancer<URLDataSyncInProps<Data>, URLDataSyncOutProps>;
export interface CursorPaginatedData<T> {
    readonly results: readonly T[];
    readonly limit?: number;
    readonly order?: string;
    readonly sortField?: Extract<keyof T, string>;
    readonly next?: string;
    readonly previous?: string;
    readonly hasNext?: boolean;
    readonly hasPrevious?: boolean;
}
export interface URLCursorPaginatedSyncInProps<T> extends StrictOmit<URLDataSyncInProps<readonly T[]>, "data">, Pick<CursorPaginatedData<T>, "hasNext" | "hasPrevious" | "limit" | "order" | "sortField"> {
    readonly data: readonly T[];
    goToNextPage(): void;
    goToPreviousPage(): void;
}
export interface URLCursorPaginatedSyncOutProps extends URLDataSyncOutProps {
}
/**
 * This HOC automatically manages pagination data sync, and is best used to
 * display table data. For other kinds of data use the data sync HOC.
 */
export declare function urlCursorPaginatedSyncHOC<T>(...args: Parameters<typeof urlDataSyncHOC>): FunctionalEnhancer<URLCursorPaginatedSyncInProps<T>, URLCursorPaginatedSyncOutProps>;
//# sourceMappingURL=dataHOC.d.ts.map